Learn R Programming

compute.es (version 0.1)

chi_to_es: Chi-Squared Statistic to Effect Size

Description

Converting Chi-squared statistic with 1 df to to an effect size of d (mean difference), g (unbiased estimate of d), r (correlation coefficient), z (Fisher's z), and log odds ratio. The variances of these estimates are also computed.

Usage

chi_to_es(chi.sq, n)

Arguments

chi.sq
Chi squared statistic from primary study.
n
Sample size in primary study.

Value

  • dStandardized mean difference (d).
  • var.dVariance of d.
  • gUnbiased estimate of d.
  • var.gVariance of g.
  • rCorrelation coefficient.
  • var.rVariance of r.
  • log_oddsLog odds ratio.
  • var.log_oddsVariance of log odds ratio.
  • nTotal sample size.

References

Borenstein (2009). Effect sizes for continuous data. In H. Cooper, L. V. Hedges, & J. C. Valentine (Eds.), The handbook of research synthesis and meta analysis (pp. 279-293). New York: Russell Sage Foundation.