Learn R Programming

compute.es (version 0.1)

mean_to_es2: Means with Pooled SD to Effect Size

Description

Converts raw mean scores with pooled standard deviation to an effect size of d (mean difference), g (unbiased estimate of d), r (correlation coefficient), z (Fisher's z), and log odds ratio. The variances of these estimates are also computed.

Usage

mean_to_es2(m.1, m.2, s.pooled, n.1, n.2)

Arguments

m.1
Mean of group one.
m.2
Mean of group two.
s.pooled
Pooled standard deviation.
n.1
Sample size of group one.
n.2
Sample size of group two.

Value

  • dStandardized mean difference (d).
  • var.dVariance of d.
  • gUnbiased estimate of d.
  • var.gVariance of g.
  • rCorrelation coefficient.
  • var.rVariance of r.
  • log_oddsLog odds ratio.
  • var.log_oddsVariance of log odds ratio.
  • nTotal sample size.

References

Borenstein (2009). Effect sizes for continuous data. In H. Cooper, L. V. Hedges, & J. C. Valentine (Eds.), The handbook of research synthesis and meta analysis (pp. 279-293). New York: Russell Sage Foundation.

See Also

mean_to_es, mean_anc_to_es, mean_anc_to_es2