Learn R Programming

compute.es (version 0.1)

r_to_es: Correlation coefficient (r) to Effect Size

Description

Converts correlation (r) to an effect size of d (mean difference), g (unbiased estimate of d), r (correlation coefficient), z (Fisher's z), and log odds ratio. The variances of these estimates are also computed.

Usage

r_to_es(r, var.r = NULL, n)

Arguments

r
Correlation coefficient.
var.r
Variance of r. If value is not reported then leave it blank and variances will be computed based on sample size. Otherwise, enter this value (e.g., r_to_es(.27, var.r = .02, 30).
n
Total sample size.

Value

  • dStandardized mean difference (d).
  • var.dVariance of d.
  • gUnbiased estimate of d.
  • var.gVariance of g.
  • rCorrelation coefficient.
  • var.rVariance of r.
  • log_oddsLog odds ratio.
  • var.log_oddsVariance of log odds ratio.
  • nTotal sample size.

References

Borenstein (2009). Effect sizes for continuous data. In H. Cooper, L. V. Hedges, & J. C. Valentine (Eds.), The handbook of research synthesis and meta analysis (pp. 279-293). New York: Russell Sage Foundation.