Learn R Programming

compute.es (version 0.1)

tt_to_es: t-test Value to Effect Size

Description

Converts a t-test value to an effect size of d (mean difference), g (unbiased estimate of d), r (correlation coefficient), z (Fisher's z), and log odds ratio. The variances of these estimates are also computed.

Usage

tt_to_es(t, n.1, n.2)

Arguments

t
t-test value reported in primary study.
n.1
Sample size of treatment group.
n.2
Sample size of comparison group.

Value

  • dStandardized mean difference (d).
  • var.dVariance of d.
  • gUnbiased estimate of d.
  • var.gVariance of g.
  • rCorrelation coefficient.
  • var.rVariance of r.
  • log_oddsLog odds ratio.
  • var.log_oddsVariance of log odds ratio.
  • nTotal sample size.

References

Borenstein (2009). Effect sizes for continuous data. In H. Cooper, L. V. Hedges, & J. C. Valentine (Eds.), The handbook of research synthesis and meta analysis (pp. 279-293). New York: Russell Sage Foundation.

See Also

tt.ancova_to_es